|Build| |Doc| |PyPI| |Contributor Covenant|

|Logo|

Timeflux
========

Timeflux is a free and open-source framework for acquiring and processing biosignals in real-time.

Use it to bootstrap your research, build brain-computer interfaces,
closed-loop biofeedback applications, interactive installations, and
more. Written in Python, it works on Linux, MacOS and Windows. Made for
researchers and hackers alike.

Installation
------------

You can easily install the latest stable release from PyPI. We higlhy recommend that you use an environment management system such as `Conda <https://docs.conda.io/en/latest/miniconda.html>`__ to keep everything tidy.

::

    $ conda create --name timeflux
    $ conda activate timeflux
    $ pip install timeflux

Getting started
---------------

`Read the documentation <https://doc.timeflux.io>`__.

.. |Build| image:: https://img.shields.io/github/workflow/status/timeflux/timeflux/build
.. |Doc| image:: https://img.shields.io/readthedocs/timeflux/latest
.. |PyPI| image:: https://img.shields.io/pypi/v/timeflux
.. |Contributor Covenant| image:: https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg
.. |Logo| image:: https://avatars3.githubusercontent.com/u/44117793?v=4&s=100